==> php81-nextcloud-28.0.2.tgz: share/nextcloud/apps/photos/l10n/es.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Enlace público",
    "Photos" : "Fotos",
    "Your memories under your control" : "Sus recuerdos bajo su control",
    "All media" : "Todos los medios",
    "Videos" : "Vídeos",
    "Albums" : "Álbumes",
    "Collaborative albums" : "Álbumes colaborativos",
    "People" : "Personas",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "On this day" : "En este día",
    "Shared with you" : "Compartido contigo",
    "Tags" : "Etiquetas",
    "Places" : "Ubicaciones",
    "Map" : "Mapas",
    "Photos settings" : "Configuración de fotos",
    "Mark selection as favorite" : "Marcar selección como favorita",
    "Add selection to favorites" : "Añadir selección a favoritos",
    "Remove selection from favorites" : "Eliminar selección de favoritos",
    "Name of the album" : "Nombre del álbum",
    "Location of the album" : "Ubicación del álbum",
    "Back" : "Atrás",
    "Add collaborators" : "Añadir colaboradores",
    "Save" : "Guardar",
    "Create album" : "Crear álbum",
    "Add to Album" : "Añadir al álbum",
    "Add selection to album {albumName}" : "Añadir selección al álbum {albumName}",
    "Shared by" : "Compartido por",
    "Create a new album." : "Crear un álbum nuevo.",
    "Create new album" : "Crear nuevo álbum",
    "New album" : "Nuevo álbum",
    "_%n item_::_%n photos and videos_" : ["%n ítem","%n fotos y videos","%n fotos y videos"],
    "Add people or groups who can edit your album" : "Añada personas o grupos que puedan editar su álbum",
    "Search people or groups" : "Buscar personas o grupos",
    "No recommendations. Start typing." : "Sin recomendaciones. Empiece a escribir.",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Eliminar {colaboratorLabel} de la lista de colaboradores",
    "Copy the public link" : "Copiar enlace público",
    "Public link copied!" : "¡Se copió el enlace público!",
    "Copy public link" : "Copiar enlace público",
    "Delete the public link" : "Borrar el enlace público",
    "Create public link share" : "Crear un enlace público compartido",
    "Share via public link" : "Compartir a través de enlace público",
    "Failed to fetch collaborators list." : "Fallo al recuperar la lista de colaboradores.",
    "Failed to update album." : "Fallo al actualizar el álbum.",
    "This collection does not exist" : "Esta colección no existe",
    "An error occurred" : "Ocurrió un error",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sin asignar","%n fotos sin asignar","%n fotos sin asignar"],
    "Favorite" : "Marcar como favorito",
    "Select image {imageName}" : "Seleccionar imagen {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "Imagen favorita, abrir la imagen \"{name}\" a tamaño completo",
    "Open the full size \"{name}\" image" : "Abrir la imagen \"{name}\" a tamaño completo",
    "Jump to {date}" : "Ir a {date}",
    "There are no photos or videos yet!" : "¡No hay fotos ni videos todavía!",
    "Add to {destination}" : "Añadir a {destination}",
    "Open the \"{name}\" folder" : "Abrir la carpeta \"{name}\"",
    "Go back" : "Ir atrás",
    "Back to {folder}" : "Atrás a {folder}",
    "Share this folder" : "Compartir esta carpeta",
    "_{years} year ago_::_{years} years ago_" : ["Hace {years} año","Hace {years} años","Hace {years} años"],
    "Enable squared photos view" : "Habilitar vista de fotos cuadradas",
    "Default Photos upload and Albums location" : "Ubicación por defecto de subida para fotos y álbumes",
    "Choose default Photos upload and Albums location" : "Ubicación por defecto de subida para Fotos y Álbumes",
    "Select the default location for your media" : "Seleccione la ubicación por defecto para sus medios",
    "Invalid location selected" : "Se seleccionó una ubicación inválida",
    "View" : "Ver",
    "Photos directory" : "Carpeta de fotos",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Desmarrcar todos",
    "Manage collaborators for this album" : "Administrar colaboradores para este álbum",
    "Open actions menu" : "Abrir menú de acciones",
    "Edit album details" : "Editar los detalles del álbum",
    "Download all files in album" : "Descargar todos los archivos del álbum",
    "Delete album" : "Eliminar álbum",
    "Download selected files" : "Descargar archivos seleccionados",
    "Remove selection from album" : "Eliminar selección del álbum",
    "This album does not have any photos or videos yet!" : "¡Este álbum no tiene fotos ni videos todavía!",
    "Add photos to this album" : "Añadir fotos a este álbum",
    "Add photos to {albumName}" : "Añadir fotos a {albumName}",
    "Manage collaborators" : "Administrar colaboradores",
    "Save collaborators for this album." : "Guardar colaboradores para este álbum",
    "Cover photo for album {albumName}" : "Foto de cubierta para el álbum {albumName}",
    "There is no album yet!" : "¡No hay álbum todavía!",
    "This person could not be found" : "Esta persona no pudo ser encontrada",
    "Rename person" : "Renombrar persona",
    "Merge with different person" : "Unir con una persona diferente",
    "Download selected photos" : "Descargar fotos seleccionadas",
    "Remove from favorites" : "Eliminar de favoritos",
    "Remove person" : "Eliminar persona",
    "Name of this person" : "Nombre de esta persona",
    "Save." : "Guardar.",
    "Merge person" : "Unir persona",
    "Move to different person" : "Mover a una persona diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover foto a una persona diferente","Mover fotos a una persona diferente","Mover fotos a una persona diferente"],
    "_Remove photo from person_::_Remove photos from person_" : ["Eliminar foto de la persona","Eliminar fotos de la persona","Eliminar fotos de la persona"],
    "This might take some time depending on the size of your photo library." : "Esto podría tomar algún tiempo dependiendo del tamaño de su biblioteca de fotos.",
    "Recognized people will show up here" : "Las personas que logren ser reconocidas se mostrarán aquí",
    "This folder does not exist" : "Esta carpeta no existe",
    "Loading folders …" : "Cargando carpetas ...",
    "No photos in here" : "No hay fotos aquí",
    "Taken on {date} at {time}" : "Tomada el {date} a las {time}",
    "This place does not have any photos or videos yet!" : "¡Esta ubicación no tiene fotos ni videos todavía!",
    "Add photos to this place" : "Añadir fotos a esta ubicación",
    "Cover photo for place {placeName}" : "Foto de cubierta para la ubicación {placeName}",
    "There is no place yet!" : "¡Todavía no hay ubicación!",
    "Cover photo for shared album {albumName}." : "Foto de cubierta para el álbum compartido {albumName}.",
    "Back to tags overview" : "Regresar a la vista general de etiquetas",
    "No photos with this tag yet" : "No hay fotos con esta etiqueta todavía",
    "No tags yet" : "Todavía no hay etiquetas",
    "Photos with tags will show up here" : "Las fotos con etiquetas aparecerán aquí",
    "Popular tags" : "Etiquetas populares",
    "Add" : "Añadir",
    "Add to album" : "Añadir al álbum",
    "Delete selection" : "Borrar la selección",
    "No photos or videos in here" : "No se encuentran fotos ni videos aquí",
    "Unassigned faces" : "Caras sin asignar",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Failed to fetch collection." : "Fallo al recuperar la colección.",
    "Failed to fetch collections list." : "Fallo al recuperar la lista de colecciones.",
    "Failed to fetch faces list." : "Fallo al recuperar la lista de caras.",
    "All your media" : "Todos sus medios",
    "Album {title}" : "Álbum {title}",
    "Shared Albums" : "Álbumes compartidos",
    "Shared album {title}" : "Álbum compartido {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos etiquetadas",
    "Tagged photo {title}" : "Foto etiquetada {title}",
    "{title}'s face" : "Rostro de {title}",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Detalles",
    "Failed to rename {oldName} to {faceName}." : "Fallo al renombrar {oldName} a {faceName}",
    "Failed to delete {faceName}." : "Fallo al borrar {faceName}",
    "Failed to delete {fileId}." : "Fallo al borrar {fileId}.",
    "Failed to delete {fileName}." : "Fallo al borrar {fileName}.",
    "Failed to set favorite state for {fileId}." : "Fallo al establecer el estado de favoritos para {fileId}.",
    "Failed to set favorite state for {fileName}." : "Fallo al establecer el estado de favoritos para {fileName}.",
    "Go back to the previous view." : "Regresar a la vista anterior.",
    "Go to the add collaborators view." : "Ir a la vista de añadir colaboradores.",
    "Create the album." : "Crear el álbum",
    "Back to the new album form." : "Regresar al formulario de álbum nuevo.",
    "_Share with %n user_::_Share with %n users_" : ["Compartir con %n usuario","Compartir con %n usuarios","Compartir con %n usuarios"],
    "Search for collaborators" : "Buscar colaboradores",
    "Add {collaboratorLabel} to the collaborators list" : "Añadir {collaboratorLabel} a la lista de colaboradores",
    "No collaborators available" : "No hay colaboradores disponibles",
    "Failed to fetch album." : "Fallo al recuperar el álbum.",
    "The file is in the favorites" : "El archivo se encuentra en los favoritos",
    "Open the \"{name}\" sub-directory" : "Abrir el subdirectorio \"{name}\"",
    "Add photos to the album" : "Añadir fotos al álbum",
    "Failed to fetch albums list." : "Fallo al recuperar la lista de álbumes.",
    "Shared albums" : "Álbumes compartidos",
    "Create a new album" : "Crear un álbum nuevo",
    "Add selection to an album" : "Añadir selección a un álbum",
    "Failed to create {albumName}." : "Fallo al crear {albumName}",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Fallo al renombrar {currentAlbumName} a {newAlbumName}."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php81-nextcloud-31.0.10.tgz: share/nextcloud/apps/photos/l10n/es.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Enlace público",
    "Photos" : "Fotos",
    "On This Day" : "En este día",
    "Your memories under your control" : "Sus recuerdos bajo su control",
    "All media" : "Todos los medios",
    "Videos" : "Vídeos",
    "Albums" : "Álbumes",
    "Collaborative albums" : "Álbumes colaborativos",
    "People" : "Personas",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "On this day" : "En este día",
    "Shared with you" : "Compartido contigo",
    "Tags" : "Etiquetas",
    "Places" : "Ubicaciones",
    "Map" : "Mapa",
    "Photos settings" : "Configuración de fotos",
    "Mark selection as favorite" : "Marcar selección como favorita",
    "Add selection to favorites" : "Añadir selección a favoritos",
    "Remove selection from favorites" : "Eliminar selección de favoritos",
    "This name is already in use." : "Este nombre ya está en uso.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no está permitido en el nombre de archivo.",
    "Invalid filename." : "Nombre de archivo inválido.",
    "Name of the album" : "Nombre del álbum",
    "Location of the album" : "Ubicación del álbum",
    "Back" : "Atrás",
    "Add collaborators" : "Añadir colaboradores",
    "Save" : "Guardar",
    "Create album" : "Crear álbum",
    "Add to Album" : "Añadir al álbum",
    "Add selection to album {albumName}" : "Añadir selección al álbum {albumName}",
    "Shared by" : "Compartido por",
    "Create a new album." : "Crear un álbum nuevo.",
    "Create new album" : "Crear nuevo álbum",
    "New album" : "Nuevo álbum",
    "_%n item_::_%n photos and videos_" : ["%n ítem","%n fotos y videos","%n fotos y videos"],
    "Failed to fetch collaborators list." : "Fallo al recuperar la lista de colaboradores.",
    "Failed to update album." : "Fallo al actualizar el álbum.",
    "Add people or groups who can edit your album" : "Añada personas o grupos que puedan editar su álbum",
    "Search people or groups" : "Buscar personas o grupos",
    "No recommendations. Start typing." : "Sin recomendaciones. Empiece a escribir.",
    "Copy the public link" : "Copiar el enlace público",
    "Public link copied!" : "¡Se copió el enlace público!",
    "Copy public link" : "Copiar enlace público",
    "Delete the public link" : "Borrar el enlace público",
    "Create public link share" : "Crear un enlace público compartido",
    "Share via public link" : "Compartir a través de enlace público",
    "This collection does not exist" : "Esta colección no existe",
    "An error occurred" : "Ocurrió un error",
    "No picture for this day" : "No hay fotos para este día",
    "Picture taken on this day will show up here." : "Las fotos tomadas este día aparecerán aquí.",
    "More photos from this day" : "Más fotos de este día",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sin asignar","%n fotos sin asignar","%n fotos sin asignar"],
    "Favorite" : "Marcar como favorito",
    "Favorite image, open the full size \"{name}\" image" : "Imagen favorita, abrir la imagen \"{name}\" a tamaño completo",
    "Open the full size \"{name}\" image" : "Abrir la imagen \"{name}\" a tamaño completo",
    "Select image {imageName}" : "Seleccionar imagen {imageName}",
    "Open the \"{name}\" folder" : "Abrir la carpeta \"{name}\"",
    "Go back" : "Ir atrás",
    "Select a custom date range" : "Seleccione un rango de fechas personalizado",
    "Select a date range" : "Seleccione un rango de fechas",
    "Date range" : "Rango de fechas",
    "Select filters" : "Seleccione filtros",
    "Dates" : "Fechas",
    "Jump to specific date in list" : "Saltar a una fecha específica en la lista",
    "Jump to {date}" : "Ir a {date}",
    "Add to {destination}" : "Añadir a {destination}",
    "The destination folder is owned by {owner}" : "La carpeta de destino es propiedad de {owner}",
    "There are no photos or videos yet!" : "¡No hay fotos ni videos todavía!",
    "_{years} year ago_::_{years} years ago_" : ["Hace {years} año","Hace {years} años","Hace {years} años"],
    "Enable squared photos view" : "Habilitar vista de fotos cuadradas",
    "Delete source directory" : "Eliminar directorio de origen",
    "Pick folder" : "Escoja la carpeta",
    "Select a source folder for your media" : "Elegir una carpeta fuente para sus medios",
    "All folders" : "Todas las carpetas",
    "Add a Photos source for the timelines" : "Añadir una fuente de fotos para las líneas de tiempo",
    "Add folder" : "Añadir carpeta",
    "Select the default upload location for your media" : "Seleccione una ubicación de subida predeterminada para sus medios",
    "Home" : "Inicio",
    "Choose default Photos upload and Albums location" : "Ubicación por defecto de subida para Fotos y Álbumes",
    "Choose a different folder" : "Elija una carpeta diferente",
    "View" : "Ver",
    "Media folders" : "Carpetas de medios",
    "Choose the folders from where photos and videos are shown." : "Seleccione las carpetas desde donde se mostrarán las fotos y videos.",
    "Upload folder" : "Subir carpeta",
    "Choose the folder where photos and albums are uploaded to." : "Elija la carpeta donde se cargan las fotos y los álbumes.",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Deseleccionar todos",
    "Add photos to this album" : "Añadir fotos a este álbum",
    "Manage collaborators for this album" : "Administrar colaboradores para este álbum",
    "Open actions menu" : "Abrir menú de acciones",
    "Edit album details" : "Editar los detalles del álbum",
    "Download all files in album" : "Descargar todos los archivos del álbum",
    "Delete album" : "Eliminar álbum",
    "Download selected files" : "Descargar archivos seleccionados",
    "Remove selection from album" : "Eliminar selección del álbum",
    "This album does not have any photos or videos yet!" : "¡Este álbum no tiene fotos ni videos todavía!",
    "Add photos to {albumName}" : "Añadir fotos a {albumName}",
    "Manage collaborators" : "Administrar colaboradores",
    "Save collaborators for this album." : "Guardar colaboradores para este álbum",
    "Cover photo for album {albumName}" : "Foto de cubierta para el álbum {albumName}",
    "There is no album yet!" : "¡No hay álbum todavía!",
    "This person could not be found" : "Esta persona no pudo ser encontrada",
    "Rename person" : "Renombrar persona",
    "Merge with different person" : "Unir con una persona diferente",
    "Download selected photos" : "Descargar fotos seleccionadas",
    "Remove from favorites" : "Eliminar de favoritos",
    "Remove person" : "Eliminar persona",
    "Name of this person" : "Nombre de esta persona",
    "Save." : "Guardar.",
    "Merge person" : "Unir persona",
    "Move to different person" : "Mover a una persona diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover foto a una persona diferente","Mover fotos a una persona diferente","Mover fotos a una persona diferente"],
    "_Remove photo from person_::_Remove photos from person_" : ["Eliminar foto de la persona","Eliminar fotos de la persona","Eliminar fotos de la persona"],
    "This might take some time depending on the size of your photo library." : "Esto podría tomar algún tiempo dependiendo del tamaño de su biblioteca de fotos.",
    "Recognized people will show up here" : "Las personas que logren ser reconocidas se mostrarán aquí",
    "This folder does not exist" : "Esta carpeta no existe",
    "Loading folders…" : "Cargando carpetas…",
    "No photos in here" : "No hay fotos aquí",
    "Taken on {date} at {time}" : "Tomada el {date} a las {time}",
    "This place does not have any photos or videos yet!" : "¡Este lugar no tiene fotos ni videos todavía!",
    "Add photos to this place" : "Añadir fotos a este lugar",
    "Cover photo for place {placeName}" : "Foto de cubierta para el lugar {placeName}",
    "There is no place yet!" : "¡Todavía no hay lugar!",
    "Cover photo for shared album {albumName}" : "Foto de la portada para el álbum compartido {albumName}",
    "Back to tags overview" : "Regresar a la vista general de etiquetas",
    "No photos with this tag yet" : "No hay fotos con esta etiqueta todavía",
    "No tags yet" : "Todavía no hay etiquetas",
    "Photos with tags will show up here" : "Las fotos con etiquetas aparecerán aquí",
    "Popular tags" : "Etiquetas populares",
    "All tags" : "Todas las etiquetas",
    "Create new album from filters" : "Crear álbum nuevo desde los filtros",
    "One of the source folders does not exist" : "Una de las carpetas fuente no existe",
    "Add to album" : "Añadir al álbum",
    "Delete selection" : "Borrar la selección",
    "No photos or videos in here" : "No hay fotos ni videos aquí",
    "Unassigned faces" : "Caras sin asignar",
    "Failed to fetch collection." : "Fallo al recuperar la colección.",
    "Failed to fetch collections list." : "Fallo al recuperar la lista de colecciones.",
    "Failed to fetch faces list." : "Fallo al recuperar la lista de caras.",
    "Error fetching files" : "Error al obtener los archivos",
    "All your media" : "Todos sus medios",
    "Album {title}" : "Álbum {title}",
    "Shared Albums" : "Álbumes compartidos",
    "Shared album {title}" : "Álbum compartido {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos etiquetadas",
    "Tagged photo {title}" : "Foto etiquetada {title}",
    "{title}'s face" : "Rostro de {title}",
    "Last week" : "Última semana",
    "Last Month" : "Último mes",
    "Custom…" : "Personalizado…",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Detalles",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Fallo al añadir {fileBaseName} a la colección {collectionFileName}",
    "Failed to delete {fileBaseName}" : "Fallo al eliminar {fileBaseName}",
    "Failed to create {collectionFileName}" : "Fallo al crear {collectionFileName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Fallo al renombrar {currentCollectionFileName} a {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "Fallo al actualizar las propiedades de {collectionFileName} con {properties}",
    "Failed to delete {collectionFileName}" : "Fallo al eliminar {collectionFileName}",
    "Failed to move {fileBaseName} to person {faceName}" : "Fallo al mover {fileBaseName} a la persona {faceName}",
    "Failed to remove {fileBaseName}" : "Fallo al quitar {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "Fallo al renombrar {oldName} a {faceName}",
    "Failed to delete {faceName}" : "Fallo al eliminar {faceName}",
    "Failed to delete {fileId}" : "Fallo al eliminar {fileId}",
    "Failed to delete {fileName}" : "Fallo al eliminar {fileName}",
    "Failed to set favorite state for {fileId}" : "Fallo al establecer el estado de favorito para {fileId}",
    "Failed to set favorite state for {fileName}" : "Fallo al establecer el estado de favorito para {fileName}",
    "Could not load photos folder" : "No se pudo cargar la carpeta de fotos",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Eliminar {colaboratorLabel} de la lista de colaboradores",
    "Back to {folder}" : "Atrás a {folder}",
    "Share this folder" : "Compartir esta carpeta",
    "Loading folders …" : "Cargando carpetas …",
    "Add" : "Añadir"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
